@@ -6,6 +6,7 @@ import weakref
 
 from dask.utils import factors
 from dask.system import CPU_COUNT
+import toolz
 
 from .spec import SpecCluster
 from ..nanny import Nanny
@@ -49,8 +50,6 @@ class LocalCluster(SpecCluster):
     asynchronous: bool (False by default)
         Set to True if using this cluster within async/await functions or within
         Tornado gen.coroutines.  This should remain False for normal use.
-    worker_kwargs: dict
-        Extra worker arguments, will be passed to the Worker constructor.
     blocked_handlers: List[str]
         A list of strings specifying a blacklist of handlers to disallow on the Scheduler,
         like ``['feed', 'run_function']``
@@ -68,6 +67,9 @@ class LocalCluster(SpecCluster):
         Network interface to use.  Defaults to lo/localhost
     worker_class: Worker
         Worker class used to instantiate workers from.
+    **worker_kwargs:
+        Extra worker arguments. Any additional keyword arguments will be passed
+        to the ``Worker`` class constructor.
 
     Examples
     --------
@@ -109,6 +111,7 @@ class LocalCluster(SpecCluster):
         blocked_handlers=None,
         interface=None,
         worker_class=None,
+        scheduler_kwargs=None,
         **worker_kwargs
     ):
         if ip is not None:
@@ -171,6 +174,7 @@ class LocalCluster(SpecCluster):
                 "nthreads": threads_per_worker,
                 "services": worker_services,
                 "dashboard_address": worker_dashboard_address,
+                "dashboard": worker_dashboard_address is not None,
                 "interface": interface,
                 "protocol": protocol,
                 "security": security,
@@ -180,16 +184,20 @@ class LocalCluster(SpecCluster):
 
         scheduler = {
             "cls": Scheduler,
-            "options": dict(
-                host=host,
-                services=services,
-                service_kwargs=service_kwargs,
-                security=security,
-                port=scheduler_port,
-                interface=interface,
-                protocol=protocol,
-                dashboard_address=dashboard_address,
-                blocked_handlers=blocked_handlers,
+            "options": toolz.merge(
+                dict(
+                    host=host,
+                    services=services,
+                    service_kwargs=service_kwargs,
+                    security=security,
+                    port=scheduler_port,
+                    interface=interface,
+                    protocol=protocol,
+                    dashboard=dashboard_address is not None,
+                    dashboard_address=dashboard_address,
+                    blocked_handlers=blocked_handlers,
+                ),
+                scheduler_kwargs or {},
             ),
         }
 
