@@ -1,9 +1,10 @@
+import asyncio
+import gc
 import math
 from time import sleep
 
 import dask
 import pytest
-from tornado import gen
 
 from distributed import Client, wait, Adaptive, LocalCluster, SpecCluster, Worker
 from distributed.utils_test import gen_test, slowinc, clean
@@ -39,13 +40,13 @@ async def test_simultaneous_scale_up_and_down(cleanup):
                 future = c.map(slowinc, [1, 1, 1], key=["a-4", "b-4", "c-1"])
 
                 while len(s.rprocessing) < 3:
-                    await gen.sleep(0.001)
+                    await asyncio.sleep(0.001)
 
                 ta = cluster.adapt(
                     interval="100 ms", scale_factor=2, Adaptive=TestAdaptive
                 )
 
-                await gen.sleep(0.3)
+                await asyncio.sleep(0.3)
 
 
 def test_adaptive_local_cluster(loop):
@@ -90,7 +91,7 @@ async def test_adaptive_local_cluster_multi_workers(cleanup):
 
             start = time()
             while not cluster.scheduler.workers:
-                await gen.sleep(0.01)
+                await asyncio.sleep(0.01)
                 assert time() < start + 15, adapt.log
 
             await c.gather(futures)
@@ -99,13 +100,13 @@ async def test_adaptive_local_cluster_multi_workers(cleanup):
             start = time()
             # while cluster.workers:
             while cluster.scheduler.workers:
-                await gen.sleep(0.01)
+                await asyncio.sleep(0.01)
                 assert time() < start + 15, adapt.log
 
             # no workers for a while
             for i in range(10):
                 assert not cluster.scheduler.workers
-                await gen.sleep(0.05)
+                await asyncio.sleep(0.05)
 
             futures = c.map(slowinc, range(100), delay=0.01)
             await c.gather(futures)
@@ -135,7 +136,7 @@ async def test_adaptive_scale_down_override(cleanup):
         ta = cluster.adapt(
             min_size=2, interval=0.1, scale_factor=2, Adaptive=TestAdaptive
         )
-        await gen.sleep(0.3)
+        await asyncio.sleep(0.3)
 
         # Assert that adaptive cycle does not reduce cluster below minimum size
         # as determined via override.
@@ -143,25 +144,26 @@ async def test_adaptive_scale_down_override(cleanup):
 
 
 @gen_test()
-def test_min_max():
-    cluster = yield LocalCluster(
+async def test_min_max():
+    cluster = await LocalCluster(
         0,
         scheduler_port=0,
         silence_logs=False,
         processes=False,
         dashboard_address=None,
         asynchronous=True,
+        threads_per_worker=1,
     )
     try:
         adapt = cluster.adapt(minimum=1, maximum=2, interval="20 ms", wait_count=10)
-        c = yield Client(cluster, asynchronous=True)
+        c = await Client(cluster, asynchronous=True)
 
         start = time()
         while not cluster.scheduler.workers:
-            yield gen.sleep(0.01)
+            await asyncio.sleep(0.01)
             assert time() < start + 1
 
-        yield gen.sleep(0.2)
+        await asyncio.sleep(0.2)
         assert len(cluster.scheduler.workers) == 1
         assert len(adapt.log) == 1 and adapt.log[-1][1] == {"status": "up", "n": 1}
 
@@ -169,25 +171,26 @@ def test_min_max():
 
         start = time()
         while len(cluster.scheduler.workers) < 2:
-            yield gen.sleep(0.01)
+            await asyncio.sleep(0.01)
             assert time() < start + 1
 
         assert len(cluster.scheduler.workers) == 2
-        yield gen.sleep(0.5)
+        await asyncio.sleep(0.5)
         assert len(cluster.scheduler.workers) == 2
         assert len(cluster.workers) == 2
         assert len(adapt.log) == 2 and all(d["status"] == "up" for _, d in adapt.log)
 
         del futures
+        gc.collect()
 
         start = time()
         while len(cluster.scheduler.workers) != 1:
-            yield gen.sleep(0.01)
+            await asyncio.sleep(0.01)
             assert time() < start + 2
         assert adapt.log[-1][1]["status"] == "down"
     finally:
-        yield c.close()
-        yield cluster.close()
+        await c.close()
+        await cluster.close()
 
 
 @pytest.mark.asyncio
@@ -210,19 +213,19 @@ async def test_avoid_churn(cleanup):
 
             for i in range(10):
                 await client.submit(slowinc, i, delay=0.040)
-                await gen.sleep(0.040)
+                await asyncio.sleep(0.040)
 
             assert len(adapt.log) == 1
 
 
-@gen_test(timeout=None)
-def test_adapt_quickly():
+@pytest.mark.asyncio
+async def test_adapt_quickly():
     """ We want to avoid creating and deleting workers frequently
 
     Instead we want to wait a few beats before removing a worker in case the
     user is taking a brief pause between work
     """
-    cluster = yield LocalCluster(
+    cluster = await LocalCluster(
         0,
         asynchronous=True,
         processes=False,
@@ -230,46 +233,46 @@ def test_adapt_quickly():
         silence_logs=False,
         dashboard_address=None,
     )
-    client = yield Client(cluster, asynchronous=True)
+    client = await Client(cluster, asynchronous=True)
     adapt = cluster.adapt(interval="20 ms", wait_count=5, maximum=10)
     try:
         future = client.submit(slowinc, 1, delay=0.100)
-        yield wait(future)
+        await wait(future)
         assert len(adapt.log) == 1
 
         # Scale up when there is plenty of available work
         futures = client.map(slowinc, range(1000), delay=0.100)
         while len(adapt.log) == 1:
-            yield gen.sleep(0.01)
+            await asyncio.sleep(0.01)
         assert len(adapt.log) == 2
         assert adapt.log[-1][1]["status"] == "up"
         d = [x for x in adapt.log[-1] if isinstance(x, dict)][0]
         assert 2 < d["n"] <= adapt.maximum
 
         while len(cluster.workers) < adapt.maximum:
-            yield gen.sleep(0.01)
+            await asyncio.sleep(0.01)
 
         del futures
 
         while len(cluster.scheduler.tasks) > 1:
-            yield gen.sleep(0.01)
+            await asyncio.sleep(0.01)
 
-        yield cluster
+        await cluster
 
         while len(cluster.scheduler.workers) > 1 or len(cluster.worker_spec) > 1:
-            yield gen.sleep(0.01)
+            await asyncio.sleep(0.01)
 
         # Don't scale up for large sequential computations
-        x = yield client.scatter(1)
+        x = await client.scatter(1)
         log = list(cluster._adaptive.log)
         for i in range(100):
             x = client.submit(slowinc, x)
 
-        yield gen.sleep(0.1)
+        await asyncio.sleep(0.1)
         assert len(cluster.workers) == 1
     finally:
-        yield client.close()
-        yield cluster.close()
+        await client.close()
+        await cluster.close()
 
 
 @gen_test(timeout=None)
@@ -288,13 +291,13 @@ async def test_adapt_down():
 
             futures = client.map(slowinc, range(1000), delay=0.1)
             while len(cluster.scheduler.workers) < 5:
-                await gen.sleep(0.1)
+                await asyncio.sleep(0.1)
 
             cluster.adapt(maximum=2)
 
             start = time()
             while len(cluster.scheduler.workers) != 2:
-                await gen.sleep(0.1)
+                await asyncio.sleep(0.1)
                 assert time() < start + 1
 
 
@@ -332,7 +335,7 @@ def test_basic_no_loop(loop):
             loop.add_callback(loop.stop)
 
 
-@gen_test(timeout=None)
+@pytest.mark.asyncio
 async def test_target_duration():
     """ Ensure that redefining adapt with a lower maximum removes workers """
     with dask.config.set(
@@ -349,12 +352,12 @@ async def test_target_duration():
             adapt = cluster.adapt(interval="20ms", minimum=2, target_duration="5s")
             async with Client(cluster, asynchronous=True) as client:
                 while len(cluster.scheduler.workers) < 2:
-                    await gen.sleep(0.01)
+                    await asyncio.sleep(0.01)
 
                 futures = client.map(slowinc, range(100), delay=0.3)
 
                 while len(adapt.log) < 2:
-                    await gen.sleep(0.01)
+                    await asyncio.sleep(0.01)
 
                 assert adapt.log[0][1] == {"status": "up", "n": 2}
                 assert adapt.log[1][1] == {"status": "up", "n": 20}
@@ -382,7 +385,7 @@ async def test_worker_keys(cleanup):
         await adaptive.adapt()
 
         while len(cluster.scheduler.workers) == 4:
-            await gen.sleep(0.01)
+            await asyncio.sleep(0.01)
 
         names = {ws.name for ws in cluster.scheduler.workers.values()}
         assert names == {"a-1", "a-2"} or names == {"b-1", "b-2"}
