@@ -1,4 +1,3 @@
-import sys
 from zlib import crc32
 
 import numpy as np
@@ -189,14 +188,13 @@ def test_itemsize(dt, size):
     assert itemsize(np.dtype(dt)) == size
 
 
-@pytest.mark.skipif(sys.version_info[0] < 3, reason="numpy doesnt use memoryviews")
 def test_compress_numpy():
     pytest.importorskip("lz4")
     x = np.ones(10000000, dtype="i4")
     frames = dumps({"x": to_serialize(x)})
     assert sum(map(nbytes, frames)) < x.nbytes
 
-    header = msgpack.loads(frames[2], raw=False, use_list=False)
+    header = msgpack.loads(frames[2], raw=False, use_list=False, strict_map_key=False)
     try:
         import blosc  # noqa: F401
     except ImportError:
@@ -233,12 +231,11 @@ def test_dont_compress_uncompressable_data():
 
 
 @gen_cluster(client=True, timeout=60)
-def test_dumps_large_blosc(c, s, a, b):
+async def test_dumps_large_blosc(c, s, a, b):
     x = c.submit(np.ones, BIG_BYTES_SHARD_SIZE * 2, dtype="u1")
-    result = yield x
+    await x
 
 
-@pytest.mark.skipif(sys.version_info[0] < 3, reason="numpy doesnt use memoryviews")
 def test_compression_takes_advantage_of_itemsize():
     pytest.importorskip("lz4")
     blosc = pytest.importorskip("blosc")
@@ -268,6 +265,7 @@ def test_large_numpy_array():
         np.broadcast_to(np.arange(10), (20, 10)),  # Some strides are 0
         np.broadcast_to(1, (3, 4, 2)),  # All strides are 0
         np.broadcast_to(np.arange(100)[:1], 5),  # x.base is larger than x
+        np.broadcast_to(np.arange(5), (4, 5))[:, ::-1],
     ],
 )
 @pytest.mark.parametrize("writeable", [True, False])
