@@ -1,5 +1,6 @@
 import asyncio
 import collections
+import gc
 from contextlib import contextmanager
 import copy
 import functools
@@ -17,7 +18,6 @@ import socket
 import subprocess
 import sys
 import tempfile
-import textwrap
 import threading
 from time import sleep
 import uuid
@@ -397,25 +397,9 @@ async def geninc(x, delay=0.02):
     return x + 1
 
 
-def compile_snippet(code, dedent=True):
-    if dedent:
-        code = textwrap.dedent(code)
-    code = compile(code, "<dynamic>", "exec")
-    ns = globals()
-    exec(code, ns, ns)
-
-
-if sys.version_info >= (3, 5):
-    compile_snippet(
-        """
-        async def asyncinc(x, delay=0.02):
-            await asyncio.sleep(delay)
-            return x + 1
-        """
-    )
-    assert asyncinc  # noqa: F821
-else:
-    asyncinc = None
+async def asyncinc(x, delay=0.02):
+    await asyncio.sleep(delay)
+    return x + 1
 
 
 _readone_queues = {}
@@ -761,8 +745,8 @@ def gen_test(timeout=10):
     """ Coroutine test
 
     @gen_test(timeout=5)
-    def test_foo():
-        yield ...  # use tornado coroutines
+    async def test_foo():
+        await ...  # use tornado coroutines
     """
 
     def _(func):
@@ -798,7 +782,7 @@ async def start_cluster(
         security=security,
         port=0,
         host=scheduler_addr,
-        **scheduler_kwargs
+        **scheduler_kwargs,
     )
     workers = [
         Worker(
@@ -809,7 +793,7 @@ async def start_cluster(
             loop=loop,
             validate=True,
             host=ncore[0],
-            **(merge(worker_kwargs, ncore[2]) if len(ncore) > 2 else worker_kwargs)
+            **(merge(worker_kwargs, ncore[2]) if len(ncore) > 2 else worker_kwargs),
         )
         for i, ncore in enumerate(nthreads)
     ]
@@ -856,14 +840,15 @@ def gen_cluster(
     active_rpc_timeout=1,
     config={},
     clean_kwargs={},
+    allow_unclosed=False,
 ):
     from distributed import Client
 
     """ Coroutine test with small cluster
 
     @gen_cluster()
-    def test_foo(scheduler, worker1, worker2):
-        yield ...  # use tornado coroutines
+    async def test_foo(scheduler, worker1, worker2):
+        await ...  # use tornado coroutines
 
     See also:
         start
@@ -905,6 +890,7 @@ def gen_cluster(
                                     "Failed to start gen_cluster, retrying",
                                     exc_info=True,
                                 )
+                                await asyncio.sleep(1)
                             else:
                                 workers[:] = ws
                                 args = [s] + workers
@@ -917,7 +903,7 @@ def gen_cluster(
                                 loop=loop,
                                 security=security,
                                 asynchronous=True,
-                                **client_kwargs
+                                **client_kwargs,
                             )
                             args = [c] + args
                         try:
@@ -940,16 +926,28 @@ def gen_cluster(
                         else:
                             await c._close(fast=True)
 
-                        for i in range(5):
-                            if all(c.closed() for c in Comm._instances):
-                                break
-                            else:
+                        def get_unclosed():
+                            return [c for c in Comm._instances if not c.closed()] + [
+                                c
+                                for c in _global_clients.values()
+                                if c.status != "closed"
+                            ]
+
+                        try:
+                            start = time()
+                            while time() < start + 5:
+                                gc.collect()
+                                if not get_unclosed():
+                                    break
                                 await asyncio.sleep(0.05)
-                        else:
-                            L = [c for c in Comm._instances if not c.closed()]
+                            else:
+                                if allow_unclosed:
+                                    print(f"Unclosed Comms: {get_unclosed()}")
+                                else:
+                                    raise RuntimeError("Unclosed Comms", get_unclosed())
+                        finally:
                             Comm._instances.clear()
-                            # raise ValueError("Unclosed Comms", L)
-                            print("Unclosed Comms", L)
+                            _global_clients.clear()
 
                         return result
 
@@ -989,12 +987,7 @@ def terminate_process(proc):
         else:
             proc.send_signal(signal.SIGINT)
         try:
-            if sys.version_info[0] == 3:
-                proc.wait(10)
-            else:
-                start = time()
-                while proc.poll() is None and time() < start + 10:
-                    sleep(0.02)
+            proc.wait(10)
         finally:
             # Make sure we don't leave the process lingering around
             with ignoring(OSError):
@@ -1108,115 +1101,106 @@ else:
     requires_ipv6 = pytest.mark.skip("ipv6 required")
 
 
-async def assert_can_connect(addr, timeout=None, connection_args=None):
+async def assert_can_connect(addr, timeout=0.5, **kwargs):
     """
     Check that it is possible to connect to the distributed *addr*
     within the given *timeout*.
     """
-    if timeout is None:
-        timeout = 0.5
-    comm = await connect(addr, timeout=timeout, connection_args=connection_args)
+    comm = await connect(addr, timeout=timeout, **kwargs)
     comm.abort()
 
 
 async def assert_cannot_connect(
-    addr, timeout=None, connection_args=None, exception_class=EnvironmentError
+    addr, timeout=0.5, exception_class=EnvironmentError, **kwargs
 ):
     """
     Check that it is impossible to connect to the distributed *addr*
     within the given *timeout*.
     """
-    if timeout is None:
-        timeout = 0.5
     with pytest.raises(exception_class):
-        comm = await connect(addr, timeout=timeout, connection_args=connection_args)
+        comm = await connect(addr, timeout=timeout, **kwargs)
         comm.abort()
 
 
-async def assert_can_connect_from_everywhere_4_6(
-    port, timeout=None, connection_args=None, protocol="tcp"
-):
+async def assert_can_connect_from_everywhere_4_6(port, protocol="tcp", **kwargs):
     """
     Check that the local *port* is reachable from all IPv4 and IPv6 addresses.
     """
-    args = (timeout, connection_args)
     futures = [
-        assert_can_connect("%s://127.0.0.1:%d" % (protocol, port), *args),
-        assert_can_connect("%s://%s:%d" % (protocol, get_ip(), port), *args),
+        assert_can_connect("%s://127.0.0.1:%d" % (protocol, port), **kwargs),
+        assert_can_connect("%s://%s:%d" % (protocol, get_ip(), port), **kwargs),
     ]
     if has_ipv6():
         futures += [
-            assert_can_connect("%s://[::1]:%d" % (protocol, port), *args),
-            assert_can_connect("%s://[%s]:%d" % (protocol, get_ipv6(), port), *args),
+            assert_can_connect("%s://[::1]:%d" % (protocol, port), **kwargs),
+            assert_can_connect("%s://[%s]:%d" % (protocol, get_ipv6(), port), **kwargs),
         ]
     await asyncio.gather(*futures)
 
 
 async def assert_can_connect_from_everywhere_4(
-    port, timeout=None, connection_args=None, protocol="tcp"
+    port, protocol="tcp", **kwargs,
 ):
     """
     Check that the local *port* is reachable from all IPv4 addresses.
     """
-    args = (timeout, connection_args)
     futures = [
-        assert_can_connect("%s://127.0.0.1:%d" % (protocol, port), *args),
-        assert_can_connect("%s://%s:%d" % (protocol, get_ip(), port), *args),
+        assert_can_connect("%s://127.0.0.1:%d" % (protocol, port), **kwargs),
+        assert_can_connect("%s://%s:%d" % (protocol, get_ip(), port), **kwargs),
     ]
     if has_ipv6():
         futures += [
-            assert_cannot_connect("%s://[::1]:%d" % (protocol, port), *args),
-            assert_cannot_connect("%s://[%s]:%d" % (protocol, get_ipv6(), port), *args),
+            assert_cannot_connect("%s://[::1]:%d" % (protocol, port), **kwargs),
+            assert_cannot_connect(
+                "%s://[%s]:%d" % (protocol, get_ipv6(), port), **kwargs
+            ),
         ]
     await asyncio.gather(*futures)
 
 
-async def assert_can_connect_locally_4(port, timeout=None, connection_args=None):
+async def assert_can_connect_locally_4(port, **kwargs):
     """
     Check that the local *port* is only reachable from local IPv4 addresses.
     """
-    args = (timeout, connection_args)
-    futures = [assert_can_connect("tcp://127.0.0.1:%d" % port, *args)]
+    futures = [assert_can_connect("tcp://127.0.0.1:%d" % port, **kwargs)]
     if get_ip() != "127.0.0.1":  # No outside IPv4 connectivity?
-        futures += [assert_cannot_connect("tcp://%s:%d" % (get_ip(), port), *args)]
+        futures += [assert_cannot_connect("tcp://%s:%d" % (get_ip(), port), **kwargs)]
     if has_ipv6():
         futures += [
-            assert_cannot_connect("tcp://[::1]:%d" % port, *args),
-            assert_cannot_connect("tcp://[%s]:%d" % (get_ipv6(), port), *args),
+            assert_cannot_connect("tcp://[::1]:%d" % port, **kwargs),
+            assert_cannot_connect("tcp://[%s]:%d" % (get_ipv6(), port), **kwargs),
         ]
     await asyncio.gather(*futures)
 
 
-async def assert_can_connect_from_everywhere_6(
-    port, timeout=None, connection_args=None
-):
+async def assert_can_connect_from_everywhere_6(port, **kwargs):
     """
     Check that the local *port* is reachable from all IPv6 addresses.
     """
     assert has_ipv6()
-    args = (timeout, connection_args)
     futures = [
-        assert_cannot_connect("tcp://127.0.0.1:%d" % port, *args),
-        assert_cannot_connect("tcp://%s:%d" % (get_ip(), port), *args),
-        assert_can_connect("tcp://[::1]:%d" % port, *args),
-        assert_can_connect("tcp://[%s]:%d" % (get_ipv6(), port), *args),
+        assert_cannot_connect("tcp://127.0.0.1:%d" % port, **kwargs),
+        assert_cannot_connect("tcp://%s:%d" % (get_ip(), port), **kwargs),
+        assert_can_connect("tcp://[::1]:%d" % port, **kwargs),
+        assert_can_connect("tcp://[%s]:%d" % (get_ipv6(), port), **kwargs),
     ]
     await asyncio.gather(*futures)
 
 
-async def assert_can_connect_locally_6(port, timeout=None, connection_args=None):
+async def assert_can_connect_locally_6(port, **kwargs):
     """
     Check that the local *port* is only reachable from local IPv6 addresses.
     """
     assert has_ipv6()
-    args = (timeout, connection_args)
     futures = [
-        assert_cannot_connect("tcp://127.0.0.1:%d" % port, *args),
-        assert_cannot_connect("tcp://%s:%d" % (get_ip(), port), *args),
-        assert_can_connect("tcp://[::1]:%d" % port, *args),
+        assert_cannot_connect("tcp://127.0.0.1:%d" % port, **kwargs),
+        assert_cannot_connect("tcp://%s:%d" % (get_ip(), port), **kwargs),
+        assert_can_connect("tcp://[::1]:%d" % port, **kwargs),
     ]
     if get_ipv6() != "::1":  # No outside IPv6 connectivity?
-        futures += [assert_cannot_connect("tcp://[%s]:%d" % (get_ipv6(), port), *args)]
+        futures += [
+            assert_cannot_connect("tcp://[%s]:%d" % (get_ipv6(), port), **kwargs)
+        ]
     await asyncio.gather(*futures)
 
 
@@ -1522,7 +1506,9 @@ def check_instances():
     }
 
     # assert not list(SpecCluster._instances)  # TODO
-    assert all(c.status == "closed" for c in SpecCluster._instances)
+    assert all(c.status == "closed" for c in SpecCluster._instances), list(
+        SpecCluster._instances
+    )
     SpecCluster._instances.clear()
 
     Nanny._instances.clear()
